@@ -87,7 +87,8 @@ sub _process_file
     my($info, $fh, $img_no) = @_;
 
     my $soi = my_read($fh, 2);
-    die "SOI missing" unless $soi eq "\xFF\xD8";
+    my $ofs = tell() - 2;
+    die "SOI missing in JPEG file at offset $ofs" unless $soi eq "\xFF\xD8";
 
     $info->push_info($img_no, "file_media_type" => "image/jpeg");
     $info->push_info($img_no, "file_ext" => "jpg");
@@ -246,9 +247,18 @@ sub process_app1_exif
     require Image::TIFF;
     my $t = Image::TIFF->new(\$data);
 
+
     for my $i (0 .. $t->num_ifds - 1) {
 	my $ifd = $t->ifd($i);
+
+#	use Data::Dumper;
+#	print STDERR Dumper($ifd);
+
 	for (@$ifd) {
+#		use Devel::Peek;
+#		print STDERR "# pushing info $i $_->[0] $_->[3]\n";
+#		print STDERR Devel::Peek::Dump($_->[3]),"\n" if $_->[0] =~ /Olympus-/;
+
 	    $info->push_info($i, $_->[0], $_->[3]);
 	}
 
